@@ -38,6 +38,7 @@ HD_DEFINE_PLUGIN_MODULE (CountdownHomeWidget, countdown_home_widget,
   HD_TYPE_HOME_PLUGIN_ITEM)
 
 gboolean countdown_home_widget_update_content (CountdownHomeWidget *self);
+static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event);
 
 gboolean check_ampm_format ()
 {
@@ -144,6 +145,19 @@ void countdown_home_widget_select_time (GtkButton *button, GtkWidget *dialog)
 	gtk_widget_hide (dialog);
 }
 
+void countdown_home_widget_select_position (GtkButton *button, GtkWidget *dialog)
+{
+	//g_warning ("countdown_home_widget_select_position");
+	HildonTouchSelector *selector = hildon_picker_dialog_get_selector (HILDON_PICKER_DIALOG (dialog));
+	
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gint current = hildon_touch_selector_get_active (selector, 0);
+	gchar *currentText = g_strdup_printf ("%d", current+1);
+	gtk_button_set_label (button, currentText);
+	g_free (currentText);
+	gtk_widget_hide (dialog);
+}
+
 void countdown_home_widget_add_event(GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_add_event");
@@ -157,7 +171,7 @@ void countdown_home_widget_add_event(GtkWidget *button, GdkEventButton *event, C
     GtkWidget *displayCaption;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-    dialog = gtk_dialog_new_with_buttons ("Add Countdown",
+    dialog = gtk_dialog_new_with_buttons ("Add Countdown Event",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
         "Save", GTK_RESPONSE_ACCEPT, NULL);
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
@@ -277,15 +291,16 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 	//g_warning ("countdown_home_widget_edit_event");
 	gint index = g_ascii_strtoll (gtk_widget_get_name (button), NULL, 10);
 	GtkWidget *dialog, *content_area;
-    GtkWidget *titleEntry, *dateButton, *timeButton;
-    GtkWidget *titleCaption, *dateCaption, *timeCaption;
-	GtkWidget *datePicker, *timePicker;
-	GtkWidget *dateSelector, *timeSelector;
+    GtkWidget *titleEntry, *dateButton, *timeButton, *positionButton;
+    GtkWidget *titleCaption, *dateCaption, *timeCaption, *positionCaption;
+	GtkWidget *datePicker, *timePicker, *positionPicker;
+	GtkWidget *dateSelector, *timeSelector, *positionSelector;
     GtkWidget *toggleYears, *toggleWeeks, *toggleDays, *toggleHours, *toggleMinutes;
     GtkWidget *displayCaption;
+	GtkTreeIter iter;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-    dialog = gtk_dialog_new_with_buttons ("Edit Countdown",
+    dialog = gtk_dialog_new_with_buttons ("Edit Countdown Event",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
         "Save", GTK_RESPONSE_ACCEPT, "Delete", GTK_RESPONSE_NO, NULL);
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
@@ -334,8 +349,29 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
     displayCaption = hildon_caption_new (group, "Display", GTK_WIDGET (hbox), NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (displayCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), displayCaption);
+	
+	positionPicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	gtk_window_set_title (GTK_WINDOW (positionPicker), "Select position");
+	positionSelector = hildon_touch_selector_new_text ();
+	
+	gint num = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (self->priv->entries), NULL);
+	gint i;
+	for (i=1; i<=num; i++) {
+		gchar *pos = g_strdup_printf ("%d", i);
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (positionSelector), pos);
+		g_free (pos);
+	}
+	
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (positionPicker), HILDON_TOUCH_SELECTOR (positionSelector));
+	
+	positionButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (positionButton), "clicked", G_CALLBACK (countdown_home_widget_select_position), positionPicker);
+	
+	positionCaption = hildon_caption_new (group, "Position", positionButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (positionCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), positionCaption);
+	
     
-	GtkTreeIter iter;
 	if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
 		gchar *titleText, *dateText, *timeText;
 		gboolean tYears, tWeeks, tDays;
@@ -372,11 +408,16 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 			strftime (timeString, 255, _("wdgt_va_24h_time"), &tm);
 		}
 		
+		gchar *positionText = g_strdup_printf ("%d", index+1);
+		
 		hildon_entry_set_text (HILDON_ENTRY (titleEntry), titleText);
 		hildon_date_selector_select_current_date (HILDON_DATE_SELECTOR (dateSelector), year, month, day);
 		gtk_button_set_label (GTK_BUTTON (dateButton), dateString);
 		hildon_time_selector_set_time (HILDON_TIME_SELECTOR (timeSelector), hour, minute);
 		gtk_button_set_label (GTK_BUTTON (timeButton), timeString);
+		hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (positionSelector), 0, index);
+		gtk_button_set_label (GTK_BUTTON (positionButton), positionText);
+		g_free (positionText);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleYears), tYears);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleWeeks), tWeeks);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleDays), tDays);
@@ -394,6 +435,9 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
         gboolean tYears, tWeeks, tDays, tHours, tMinutes;
         gchar *printDate, *printTime, *compTime;
 		GtkTreeIter iter;
+		GtkTreeIter pos;
+		gint position = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (positionSelector), 0);
+		gint total = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (self->priv->entries), NULL) - 1;
 
         hildon_date_selector_get_date (HILDON_DATE_SELECTOR (dateSelector), &year, &month, &day);
         hildon_time_selector_get_time (HILDON_TIME_SELECTOR (timeSelector), &hours, &minutes);
@@ -411,6 +455,16 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
 			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
 			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
+			
+			if (position == 0) {
+				gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &pos, NULL, position);
+				gtk_list_store_move_before (self->priv->entries, &iter, &pos);
+			} else if (position < total ) {
+				gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &pos, NULL, position);
+				gtk_list_store_move_after (self->priv->entries, &iter, &pos);
+			} else {
+				gtk_list_store_move_before (self->priv->entries, &iter, NULL);
+			}
 		}
 
         g_free (printDate);
@@ -603,7 +657,6 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
 	GtkWidget *addEvent = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (addEvent), FALSE);
 	gtk_container_add (GTK_CONTAINER (addEvent), addNewCountdown);
-	//gtk_button_set_image (GTK_BUTTON (addNewCountdown), addImage);
 
     self->priv->buttons = GTK_HBOX (gtk_hbox_new (TRUE, 0));
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->buttons), 0);
@@ -629,9 +682,10 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self->priv->homeWidget), align);
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->buttons), FALSE, FALSE, 0);
+	
+	g_signal_connect (self->priv->buttons, "expose-event", G_CALLBACK (countdown_home_widget_expose_button_area), NULL);
+	
     gtk_widget_show_all (self->priv->homeWidget);
-	//gtk_widget_hide (self->priv->upButton);
-	//gtk_widget_hide (self->priv->downButton);
 }
 
 gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
@@ -773,6 +827,13 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 		GtkWidget *vbox = gtk_vbox_new (TRUE, 0);
 		GtkWidget *titleLabel = gtk_label_new (title);
 		GtkWidget *contentLabel = gtk_label_new (contentLabelText);
+		//GdkColor color;
+		//gtk_widget_ensure_style (contentLabel);
+		//gtk_style_lookup_color (contentLabel->style, "SecondaryTextColor", &color);
+		//g_warning ("%s", gdk_color_to_string (&color));
+		//gtk_widget_modify_text (contentLabel, GTK_STATE_ACTIVE, &color);
+		
+		gtk_label_set_markup (GTK_LABEL (contentLabel), g_strconcat ("<small>", contentLabelText, "</small>", NULL));
 		gtk_container_add (GTK_CONTAINER (event), vbox);
 		gtk_container_add (GTK_CONTAINER (vbox), titleLabel);
 		gtk_container_add (GTK_CONTAINER (vbox), contentLabel);
@@ -877,24 +938,60 @@ static void countdown_home_widget_realize (GtkWidget *widget)
 	GTK_WIDGET_CLASS (countdown_home_widget_parent_class)->realize (widget);
 }
 
+static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event)
+{
+	cairo_t *cr;
+
+    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+	gdk_cairo_region (cr, event->region);
+	cairo_clip (cr);
+
+    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+    
+	gint width, height, x, y, radius=10;
+	width = widget->allocation.width;
+	height = widget->allocation.height;
+	x = widget->allocation.x;
+	y = widget->allocation.y;
+
+	cairo_move_to(cr, x + radius, y);
+	cairo_line_to(cr, x + width - radius, y);
+	cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
+				y + radius);
+	cairo_line_to(cr, x + width, y + height - radius);
+	cairo_curve_to(cr, x + width, y + height - radius, x + width,
+				y + height, x + width - radius, y + height);
+	cairo_line_to(cr, x + radius, y + height);
+	cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
+				y + height - radius);
+	cairo_line_to(cr, x, y + radius);
+	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
+
+	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+
+	cairo_fill(cr);
+
+    cairo_destroy (cr);
+	
+	return FALSE;
+}
+
 static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventExpose *event)
 {
 	//g_warning ("countdown_home_widget_expose_event");
 	cairo_t *cr;
 
-	/* Create cairo context */
     cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
 
-    /* Draw alpha background */
     cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
     cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.0);
     cairo_paint (cr);
 
-    /* Free context */
     cairo_destroy (cr);
 	
 	cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
-	cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+	cairo_set_source_rgba (cr, 0.25, 0.25, 0.25, 0.5);
 	
 	gint width, height, x, y, radius=10;
 	width = widget->allocation.width;
@@ -915,7 +1012,6 @@ static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventE
 	cairo_line_to(cr, x, y + radius);
 	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
 
-	/* Draw alpha background */
 	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
 	cairo_fill(cr);
